==> igniteui-webcomponents-core-4.0.2.tgz: package/esm2015/lib/UploadDataCompletedEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { AsyncCompletedEventArgsDescriptionMetadata } from "./AsyncCompletedEventArgsDescriptionMetadata";
import { UploadDataCompletedEventArgsDescription } from "./UploadDataCompletedEventArgsDescription";
/**
 * @hidden
 */
export let UploadDataCompletedEventArgsDescriptionMetadata = /*@__PURE__*/ (() => {
    class UploadDataCompletedEventArgsDescriptionMetadata extends Base {
        static b(a) {
            if (UploadDataCompletedEventArgsDescriptionMetadata.a == null) {
                UploadDataCompletedEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                UploadDataCompletedEventArgsDescriptionMetadata.c(UploadDataCompletedEventArgsDescriptionMetadata.a);
            }
            if (a.j(UploadDataCompletedEventArgsDescriptionMetadata.a)) {
                return;
            }
            a.y(UploadDataCompletedEventArgsDescriptionMetadata.a);
        }
        static c(a) {
            AsyncCompletedEventArgsDescriptionMetadata.c(a);
        }
        static d(a) {
            UploadDataCompletedEventArgsDescriptionMetadata.b(a);
            a.aa("UploadDataCompletedEventArgs", () => new UploadDataCompletedEventArgsDescription());
            a.z("UploadDataCompletedEventArgs", UploadDataCompletedEventArgsDescriptionMetadata.a);
        }
    }
    UploadDataCompletedEventArgsDescriptionMetadata.$t = /*@__PURE__*/ markType(UploadDataCompletedEventArgsDescriptionMetadata, 'UploadDataCompletedEventArgsDescriptionMetadata');
    UploadDataCompletedEventArgsDescriptionMetadata.a = null;
    return UploadDataCompletedEventArgsDescriptionMetadata;
})();

==> igniteui-webcomponents-core-4.2.5.tgz: package/esm2015/lib/UploadDataCompletedEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { AsyncCompletedEventArgsDescriptionMetadata } from "./AsyncCompletedEventArgsDescriptionMetadata";
import { UploadDataCompletedEventArgsDescription } from "./UploadDataCompletedEventArgsDescription";
/**
 * @hidden
 */
export let UploadDataCompletedEventArgsDescriptionMetadata = /*@__PURE__*/ (() => {
    class UploadDataCompletedEventArgsDescriptionMetadata extends Base {
        static b(a) {
            if (UploadDataCompletedEventArgsDescriptionMetadata.a == null) {
                UploadDataCompletedEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                UploadDataCompletedEventArgsDescriptionMetadata.c(UploadDataCompletedEventArgsDescriptionMetadata.a);
            }
            if (a.k(UploadDataCompletedEventArgsDescriptionMetadata.a)) {
                return;
            }
            a.aa(UploadDataCompletedEventArgsDescriptionMetadata.a);
        }
        static c(a) {
            AsyncCompletedEventArgsDescriptionMetadata.c(a);
        }
        static d(a) {
            UploadDataCompletedEventArgsDescriptionMetadata.b(a);
            a.ac("UploadDataCompletedEventArgs", () => new UploadDataCompletedEventArgsDescription());
            a.ab("UploadDataCompletedEventArgs", UploadDataCompletedEventArgsDescriptionMetadata.a);
        }
    }
    UploadDataCompletedEventArgsDescriptionMetadata.$t = /*@__PURE__*/ markType(UploadDataCompletedEventArgsDescriptionMetadata, 'UploadDataCompletedEventArgsDescriptionMetadata');
    UploadDataCompletedEventArgsDescriptionMetadata.a = null;
    return UploadDataCompletedEventArgsDescriptionMetadata;
})();
